/** 
 *   Camera Control for STAR I.
 *
 *   (c) Copyright 2004 Federico Bareilles <fede@iar.unlp.edu.ar>,
 *   Instituto Argentino de Radio Astronomia (IAR).
 *
 *   This program is free software; you can redistribute it and/or
 *   modify it under the terms of the GNU General Public License as
 *   published by the Free Software Foundation; either version 2 of
 *   the License, or (at your option) any later version.
 *     
 *   The author does NOT admit liability nor provide warranty for any
 *   of this software. This material is provided "AS-IS" in the hope
 *   that it may be useful for others.
 *
 **/

#ifndef _FITS_IO_H
#define _FITS_IO_H

#include <fitsio.h>
#include "camera_setup.h"

struct fit_tag {
	char tag[FLEN_KEYWORD];
	char str[FLEN_COMMENT];
	char comment[FLEN_KEYWORD];
	struct fit_tag *next;
};

#define IMAGE_2D_RA      0x01 
#define IMAGE_2D_DEC     0x02 
#define IMAGE_2D_EQUINOX 0x04
#define IMAGE_2D_ERROR   0x10  

struct image_2d {
	char object[FLEN_VALUE];   /* Name of object */
	char filter[FLEN_VALUE];   /* Filter description */ 
	char observer[FLEN_VALUE]; /* Observer(s) */
	//char sysuser[FLEN_VALUE];  /* System user name */
	char date_obs[FLEN_VALUE]; /* UT Date of observation (YYYY-MM-DD) */
	char time_obs[FLEN_VALUE]; /* Universal time (UTC) at exposure start */
	double tjd;
	char ra_cat[FLEN_VALUE];
	char dec_cat[FLEN_VALUE];
	double equinox; /* Julian epoch of ra and dec */
	char ra[FLEN_VALUE];
	char dec[FLEN_VALUE];
	/* Site & Instrument: */
//	char origin[FLEN_VALUE];
	char observat[FLEN_VALUE];
	char telescope[FLEN_VALUE];
	char instrument[FLEN_VALUE];
	double latitude; 
	double longitude;
	double altitude;
	double gst;
	double lst;
	double ha;
	double z;
	double azimuth;
	double airmas;
	double pixscale;
	struct fit_tag *ft;
	struct camera_setup s;
	int flat_type;
	int *data;
	int datamin;
	int datamax;
	int max_count;
	int read_flag; /* for IMAGE_2D_* */
};

int fits_print_err(int status);
int comment_push(struct fit_tag *ft, char *text);
int fits_tag_push(struct fit_tag *ft, char *tag, char *text, char *comment);
int fits_tag_free(struct fit_tag *ft);
int image_2d_save(char *filename, struct image_2d *im);
int image_2d_free(struct image_2d *im);
int image_add_tag(char *filename, struct fit_tag *tag);


#endif /* _FITS_IO_H */
